<?php
/**
 * Admin Filter
 * @package     Woocommerce Purolator Small
 * @author      <https://eniture.com/>
 * @copyright   Copyright (c) 2017, Eniture
 */
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Introduce purolator Small method
 * @param array $methods
 * @return string
 */
function add_purolator_small($methods) {
    $methods['purolator_small'] = 'WC_purolator_small';
    return $methods;
}

/**
 * purolator Small method settings
 * @param $settings
 */
function purolator_small_shipping_sections($settings) {
    include( 'purolator-small-tab-class.php' );
    return $settings;
}

/**
 * purolator Small Hide Other Shipping Methods
 * @param $available_methods
 */
function purolator_small_hide_shipping($available_methods) {
    if (get_option('allow_other_plugins_purolator_small') == 'no') {
        if (count($available_methods) > 0) {
            $plugins_array = array();
            $speedship_rates = array();
            $eniture_plugins = get_option('EN_Plugins');
            if ($eniture_plugins) {
                $plugins_array = json_decode($eniture_plugins);
            }

            foreach ( $available_methods as $index => $method ){
                if ( !($method->method_id == 'speedship' || $method->method_id == 'ltl_shipping_method' || in_array( $method->method_id, $plugins_array )) ) {
                    unset($available_methods[$index]);
                }
            }
        }
    } 
    return $available_methods;
}
/**
 * Remove Other SHipping
 * @param $available_methods
 * @return array
 */
function purolator_small_remove_shipping_method($available_methods) {

    $speedship_rates = array();
    if (count($available_methods) > 0) {
        foreach ($available_methods as $index => $method) {
            if($method->method_id != 'purolator_small'){
                $speedship_rates[$index] = $available_methods[$index];
            }
        }
        return $speedship_rates;
    }
}

/**
 * Shipping Message On Cart If No Method Available
 */
function purolator_small_no_method_available() {
    $allow_checkout = ( isset($_POST['allow_proceed_checkout_purolator_small']) ) ? sanitize_text_field( $_POST['allow_proceed_checkout_purolator_small'] ) : get_option('allow_proceed_checkout_purolator_small');
    $prevent_checkout = ( isset($_POST['prevent_proceed_checkout_purolator_small']) ) ? sanitize_text_field( $_POST['prevent_proceed_checkout_purolator_small'] ) : get_option('prevent_proceed_checkout_purolator_small');

    if (get_option('allow_proceed_checkout_purolator_small') !== false) {
        update_option('allow_proceed_checkout_purolator_small', $allow_checkout);
        update_option('prevent_proceed_checkout_purolator_small', $prevent_checkout);
    } else {
        $deprecated = null;
        $autoload = 'no';
        add_option('allow_proceed_checkout_purolator_small', $allow_checkout, $deprecated, $autoload);
        add_option('prevent_proceed_checkout_purolator_small', $prevent_checkout, $deprecated, $autoload);
    }
}

  
/**
 * Filter For CSV Export
 */
add_filter('woocommerce_product_export_meta_value', 'purolator_small_dropship_location_csv', '99', '4');

/**
 * Change dropship location value
 * @param $metaValue
 * @param $meta
 * @param $product
 * @param $row
 * @return string
 */
function purolator_small_dropship_location_csv( $metaValue, $meta, $product, $row ) {

    $needle = "a:";
    if (strpos($metaValue, $needle) !== false) {
        $dsLocationIdArr = maybe_unserialize($metaValue);
        foreach ($dsLocationIdArr as $key => $dsLocationId) {
            $metaValue = purolator_small_get_dropship_address($dsLocationId);

        }

    }
    return $metaValue;
}
/**
     * Drop ship address
     * @global $wpdb
     * @param $dsLocationId
     * @return string
     */
function purolator_small_get_dropship_address($dsLocationId) {
    global $wpdb;
    $location = "";

    if(!empty($dsLocationId) && $dsLocationId != 0){
        $dropship = reset($wpdb->get_results(
                        "SELECT nickname, city, state, zip, country 
                  FROM ".$wpdb->prefix . "warehouse WHERE id=$dsLocationId"
                ));
        $location = $dropship->nickname.','.$dropship->zip.','.$dropship->city.','.$dropship->state.','.$dropship->country;
    }
    return $location;
}

 /**
     * Filter For CSV Import
     */
add_filter('woocommerce_product_importer_parsed_data', 'purolator_small_import_dropship_location_csv','99','2');

/**
 * Import drop ship location CSV
 * @param $data
 * @param $this
 * @return array
 */
function purolator_small_import_dropship_location_csv($data, $parseData) {

    foreach ($data['meta_data'] as $key => $metaData) {
        if($metaData['key'] == '_dropship_location'){
            $metaValue = explode(',', $metaData['value']);
            if(count($metaValue) > 1){
                $location = purolator_small_serialize_dropship($metaValue);
            }else{
                $location = $metaValue;
            }

            $data['meta_data'][$key]['value'] = $location;
        }
    }
    return $data;
}
 /**
     * Serialize drop ship
     * @global $wpdb
     * @param $metaValue
     * @return string
     */
function purolator_small_serialize_dropship($metaValue) {
    global $wpdb;
    $dropship = (array)reset($wpdb->get_results(
                    "SELECT id
                    FROM ".$wpdb->prefix . "warehouse WHERE nickname='$metaValue[0]' AND zip='$metaValue[1]' AND city='$metaValue[2]' AND state='$metaValue[3]' AND country='$metaValue[4]'"
            ));

    $dropship = array_map( 'intval', $dropship );

    if(empty($dropship['id'])){
        $data = purolator_small_csv_import_dropship_data( $metaValue );
        $wpdb->insert(
            $wpdb->prefix.'warehouse', $data
        );

        $dsId[] = $wpdb->insert_id;
    }else{
        $dsId[] = $dropship['id'];
    }

    $sereializedData = maybe_serialize($dsId);
    return $sereializedData;
}

/**
 * Filtered Data Array
 * @param $metaValue
 * @return array
 */
function purolator_small_csv_import_dropship_data( $metaValue ) {
    return array(
        'city'      => $metaValue[2],
        'state'     => $metaValue[3],
        'zip'       => $metaValue[1],
        'country'   => $metaValue[4],
        'location'  => 'dropship',                     
        'nickname'  => ( isset( $metaValue[0] ) ) ? $metaValue[0] : "",
    );
}