<?php
/**
 * Package Group
 * @package     Woocommerce Purolator Small
 * @author      <https://eniture.com/>
 * @copyright   Copyright (c) 2017, Eniture
 */
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Get Shipping Package Class
 */

class purolator_Small_Shipping_Get_Package {

    /** Global variable */ public $hasLTLShipment = 0;
    /** Global variable */ public $errors = array();
    public $order_details;

    /**
     * Grouping For Shipments
     * @global $woocommerce
     * @param $package
     * @param $purolator_small_res_inst
     * @return array
     */
    function group_purolator_small_shipment($package, $purolator_small_res_inst)
    {
        global $woocommerce;
        $pStatus = (isset($package['itemType'])) ? $package['itemType'] : "";
        $purolator_small_woo_obj = new purolator_Small_Woo_Update_Changes();
        $sm_zipcode = $purolator_small_woo_obj->purolator_small_postcode();
        $purolator_small_package = array();
        if (isset($package['contents'])) {
            $pack = $package['contents'];
        foreach ($pack as $item_id => $values)
        {
            $locationId = 0;
            $_product = $values['data'];
            $height = wc_get_dimension($_product->get_height(), 'in');
            $width = wc_get_dimension($_product->get_width(), 'in');
            $length = wc_get_dimension($_product->get_length(), 'in');
            $product_weight = round(wc_get_weight($_product->get_weight(), 'lbs'), 2);
            $dimenssions = $length * $width * $height;
            $exceedWeight = get_option('en_plugins_return_LTL_quotes');
            $weight = ( $product_weight * $values['quantity'] );
            $freight_enable_class = $this->purolator_small_check_freight_class($_product);
            $locations_list = $this->purolator_small_origin_address($values, $_product);
            $origin_address = $purolator_small_res_inst->purolator_Small_multi_warehouse($locations_list, $sm_zipcode);
            $hazardous_material = $this->purolator_small_get_harazdous_material($values, $_product);            
            $ptype = $this->purolator_small_check_product_type( $freight_enable_class, $exceedWeight, $product_weight );
            if (!empty($origin_address)) {
                $locationId = $origin_address['locationId'];
                $purolator_small_package[$locationId]['origin'] = $origin_address;
                $purolator_small_package[$locationId]['origin']['ptype'] = $ptype;

                if (!$_product->is_virtual()) {
                    $purolator_small_package[$locationId]['items'][] = $this->purolator_small_get_items_data($values, $_product, $product_weight, $length, $width, $height, $hazardous_material, $ptype);
                    $purolator_small_package[$locationId]['hazardousMaterial'] = $this->purolator_small_get_hazardous_index($purolator_small_package[$locationId]['items']);
                }
            }            
            if ( $pStatus == '' && $ptype == 'ltl' ) {
                return $purolator_small_package = array();
            }            
            if( $dimenssions == 0 && $product_weight == 0 ){
                $purolator_small_package[$locationId]['no_parameter'] = 'NOPARAM';
            }
            /* Order widget details */
            if(isset($purolator_small_package[$locationId]['origin'])) {
                $this->order_details['details'][$purolator_small_package[$locationId]['origin']['zip']] = $purolator_small_package[$locationId];
                $this->order_details['details'][$purolator_small_package[$locationId]['origin']['zip']]['location_type'] = $purolator_small_package[$locationId]['origin']['location'];
            }
                                     

        }
        
        return $purolator_small_package;
    }
        return false;
    }

    /**
     * products items array
     * @param $values
     * @param $_product
     * @param $product_weight
     * @param $length
     * @param $width
     * @param $height
     * @param $hazardous_material
     * @param $ptype
     * @return array
     */
    function purolator_small_get_items_data($values, $_product, $product_weight, $length, $width, $height, $hazardous_material, $ptype)
    {
        $items_data_arr = array(
            'productId'         => $_product->get_id(),
            'productName'       => $_product->get_title(),
            'productQty'        => $values['quantity'],
            'productPrice'      => $_product->get_price(),
            'productWeight'     => $product_weight,
            'productLength'     => $length,
            'productWidth'      => $width,
            'productHeight'     => $height,
            'hazardousMaterial' => ($hazardous_material == 'yes') ? 'yes' : 'no',
            'ptype'             => $ptype
        );
        return $items_data_arr;
    }

    /**
     * hazadous material is on or off
     * @param $purolator_small_package_items
     */
    function purolator_small_get_hazardous_index($purolator_small_package_items) {

        $hazrdousMaterialIndex = array_map(
                function($iCost) {
            return $iCost['hazardousMaterial'];
        }, $purolator_small_package_items
        );

        $purolator_small_package_hazardous_material = ( in_array('yes', $hazrdousMaterialIndex) ) ? 'yes' : 'no';
        return $purolator_small_package_hazardous_material;
    }

    /**
     * hazadous material is on or off
     * @param $values
     * @param $_product
     */
    function purolator_small_get_harazdous_material($values, $_product) {

        if ($_product->get_type() == 'variation') {
            $hazardous_material = get_post_meta($values['variation_id'], '_hazardousmaterials', true);
        } else {
            $hazardous_material = get_post_meta($_product->get_id(), '_hazardousmaterials', true);
        }

        return $hazardous_material;
    }

    /**
     * Get Enabled Shipping Class Of Product
     * @param $_product
     */
    function purolator_small_check_freight_class($_product) {
        if ($_product->get_type() == 'variation') {

            $ship_class_id = $_product->get_shipping_class_id();

            if ($ship_class_id == 0) {
                $parent_data = $_product->get_parent_data();
                $get_parent_term = get_term_by('id', $parent_data['shipping_class_id'], 'product_shipping_class');
                $freight_enable_class = ( isset($get_parent_term->slug) ) ? $get_parent_term->slug : "";
            } else {
                $freight_enable_class = $_product->get_shipping_class();
            }
        } else {
            $freight_enable_class = $_product->get_shipping_class();
        }

        return $freight_enable_class;
    }

    /**
     * Check Product Type
     * @param $freight_enable_class
     * @param $exceedWeight
     * @param $weight
     * @return string
     */
    function purolator_small_check_product_type($freight_enable_class, $exceedWeight, $weight) {
        if ($freight_enable_class == 'ltl_freight') {
            $ptype = 'ltl';
        } elseif ($exceedWeight == 'yes' && $weight > 150) {
            $ptype = 'ltl';
        } else {
            $ptype = 'small';
        }

        return $ptype;
    }

    /**
     * Get Origin Address
     * @global $wpdb
     * @param $values
     * @param $_product
     */
    function purolator_small_origin_address($values, $_product) {
        global $wpdb;

        ( isset($values['variation_id']) && $values['variation_id'] > 0 ) ? $post_id = $values['variation_id'] : $post_id = $_product->get_id();

        $enable_dropship = get_post_meta($post_id, '_enable_dropship', true);
        if ($enable_dropship == 'yes') {
            $get_loc = get_post_meta($post_id, '_dropship_location', true);

            if ($get_loc == '') {
                return array('error' => 'purolator small dp location not found!');
            }

            $get_loc = ( $get_loc !== '' ) ? maybe_unserialize($get_loc) : $get_loc;
            $get_loc = is_array($get_loc) ? implode(" ', '", $get_loc) : $get_loc;

            $locations_list = $wpdb->get_results(
                    "SELECT id, city, state, zip, country, location, nickname FROM " . $wpdb->prefix . "warehouse WHERE id IN ('" . $get_loc . "')"
            );
        } else {

            $locations_list = $wpdb->get_results(
                    "SELECT id, city, state, zip, country, location FROM " . $wpdb->prefix . "warehouse WHERE location = 'warehouse'"
            );
        }

        return $locations_list;
    }

}
