<?php
/**
 * Shipping Class
 * @package     Woocommerce Purolator Small
 * @author      <https://eniture.com/>
 * @copyright   Copyright (c) 2017, Eniture
 */
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Initialization
 */
function purolator_small_init()
{
    if (!class_exists('WC_purolator_small')) {

        /**
         * purolator Small Shipping Calculation Class
         */
        class WC_purolator_small extends WC_Shipping_Method
        {

            /** global variable */ public $smpkgFoundErr = array();

            /** global variable */ public $smpkgQuoteErr = array();
            public $order_detail;
            public $is_autoresid;
            public $accessorials;
            public $helper_obj;

            /**
             * Woocommerce Shipping Field Attributes
             * @param $instance_id
             */
            public function __construct($instance_id = 0)
            {
                $this->id = 'purolator_small';
                $this->helper_obj = new En_Pur_Sml_Helper_Class();
                $this->instance_id = absint($instance_id);
                $this->method_title = __('Purolator');
                $this->method_description = __('shipping rates from Purolator.');
                $this->supports = array(
                    'shipping-zones',
                    'instance-settings',
                    'instance-settings-modal',
                );
                $this->enabled = "yes";
                $this->title = "Small Package Quotes - Purolator Edition";
                $this->init();
                add_action('woocommerce_checkout_update_order_review',
                    array($this, 'calculate_shipping'));
            }

            /**
             * Update purolator Small Woocommerce Shipping Settings
             */
            function init()
            {
                $this->init_form_fields();
                $this->init_settings();
                add_action('woocommerce_update_options_shipping_' . $this->id,
                    array($this, 'process_admin_options'));
            }

            /**
             * Enable Woocommerce Shipping For purolator Small
             */
            function init_form_fields()
            {
                $this->instance_form_fields = array(
                    'enabled' => array(
                        'title' => __('Enable / Disable', 'purolator_small'),
                        'type' => 'checkbox',
                        'label' => __('Enable This Shipping Service',
                            'purolator_small'),
                        'default' => 'no',
                        'id' => 'purolator_small_enable_disable_shipping'
                    )
                );
            }

            /**
             * Calculate Shipping Rates For purolator Small
             * @param $package
             * @return boolean|string
             */
            public function calculate_shipping($package = array())
            {

                if(is_admin()) {
                    return false;
                }

                $coupn = WC()->cart->get_coupons();
                if (isset($coupn) && !empty($coupn)) {
                    $freeShipping = $this->purolatorSmpkgFreeShipping($coupn);
                    if ($freeShipping == 'y')
                        return FALSE;
                }

                $purolator_small_woo_obj = new purolator_Small_Woo_Update_Changes();
                $freight_zipcode = (strlen(WC()->customer->get_shipping_postcode()) > 0) ? WC()->customer->get_shipping_postcode() : $purolator_small_woo_obj->purolator_small_postcode();

                if (empty($freight_zipcode)) {
                    return false;
                }

                $get_packg_obj = new purolator_Small_Shipping_Get_Package();
                $purolator_small_res_inst = new purolator_Get_Shipping_Quotes();
                $rates = array();
                $rateArray = array();
                $quotesArray = array();
                $quotes = array();
                $SmPkgWebServiceArr = array();
                $purolator_small_package = "";
                $purolator_small_package = $get_packg_obj->group_purolator_small_shipment($package,
                    $purolator_small_res_inst);
                $no_param_multi_ship = 0;

                $SmPkgWebServiceArr = $purolator_small_res_inst->purolator_Small_shipping_array($purolator_small_package,
                    $package);
                
                
                foreach ($SmPkgWebServiceArr as $locId => $sPackage) {

                    if ($sPackage != 'ltl') {
                        $quotesValue = $purolator_small_res_inst->purolator_small_get_quotes($sPackage);
                        $hazardousIndex = array(
                            "hazardousMaterial" => $sPackage["hazardousMaterial"]
                        );
                        $quotes[$locId] = (object) array_merge((array) $quotesValue,
                                (array) $hazardousIndex);
                    }
                }
               
                do_action('en_save_3dbin_session', $quotes);

                  $error_index_value = array();
                foreach ($quotes as $index => $quote) {
                   
                   if ( isset( $quote->severity) &&  $quote->severity == "ERROR" )  {
                       $error_index_value[] = 'error';
                   }
                   elseif (isset( $quote->severity) &&  $quote->severity == "ERROR" ) {
                       
                       $error_index_value[] = 'error';
                   }
                }
                if (in_array("error", $error_index_value)) {
                    add_filter('woocommerce_cart_no_shipping_available_html',
                        array($this, 'purolator_small_cart_no_quotes_msg'));
                    //return 'error';
                }
                
                foreach ($quotes as $qIndex => $quote) {
                    if (!empty($quote) && isset($quote->q)) {
                        $quotesArray[$qIndex] = $quote;
                    }
                    elseif (isset($quote->RateReplyDetails)) {
                        $quotesArray[$qIndex]['RateReplyDetails'] = $quote->RateReplyDetails;
                    } else {
                        $quotesArray[$qIndex]['RateReplyDetails'] = 'Error';
                    }
                }
                if (count($quotesArray) > 1 || $no_param_multi_ship == 1) {

                    $purolator_sm_multi_shipment_quotes = $purolator_small_res_inst->purolator_small_quotes_grouping($quotesArray);
                    if (isset($purolator_sm_multi_shipment_quotes) && $purolator_sm_multi_shipment_quotes['cost'] > 0) {
                        $rates['multi_purolator_small'] = array(
                            'id' => 'multi_purolator_small',
                            'label' => 'Shipping',
                            'cost' => $purolator_sm_multi_shipment_quotes['cost'],
                            'minPrices' => $purolator_sm_multi_shipment_quotes['minPrices']
                        );
                    }
                    
                    if (isset($rates)) {
                        foreach ($rates as $rate) {

                            $this->add_rate($rate);
                        }
                    }

                    /* Order details */
                    if (!empty($rates)) {
                        
                        /* Set cheapest services */
                        $get_packg_obj->order_details['services'] = $rates;
                        $this->en_order_details_hooks_process($get_packg_obj);
                    }
                    
                    return $rates;
                }
                else {

                    $rate = array();
                    foreach ($quotesArray as $value) {
                        $services = $purolator_small_res_inst->parse_purolator_small_output($value);

                        if (isset($services)) {
                            foreach ($services as $service) {

                                if (isset($service['TotalPrice']) && $service['TotalPrice'] > 0) {
                                    $rate = array(
                                        'id' => $service['ServiceID'],
                                        'cost' => $service['TotalPrice'],
                                        'label' => $service['title'],
                                    );

                                    $rateArray[] = $rate;

                                    if (isset($rate)) {

                                        $this->add_rate($rate);
                                    }
                                }
                            }
                        }
                    }
                    /* Assign services for order details */
                    $get_packg_obj->order_details['services'] = $rateArray;
                    if (!empty($rateArray)) {
                        $this->en_order_details_hooks_process($get_packg_obj);
                    }

                    return $rateArray;
                }
            }

            /**
             * Filter function to update order details.
             * @param array $data
             * @return type
             */
            public function en_update_order_data($data)
            {
                $data['en_shipping_details']['en_puro_small'] = $this->order_detail;
                return $data;
            }

            /**
             * Function to update the filter data and session with order details.
             * @param object $group_small_shipments
             */
            public function en_order_details_hooks_process($group_small_shipments)
            {
                $order_details = array();
                $this->order_detail = $group_small_shipments->order_details;


                /* Filter the data of order details */
                add_filter('en_fitler_order_data',
                    array($this, 'en_update_order_data'));

                /* Passing empty array because data is updated using class property */
                $session_order_details = apply_filters(
                    'en_fitler_order_data', array()
                );
                
                /* Set the session */
                WC()->session->set(
                    'en_order_detail', $session_order_details
                );
            }

            /**
             * No Quotes Messages
             * Saved At Quotes Setting Page
             */
            function purolator_small_cart_no_quotes_msg()
            {
                if (get_option('wc_pervent_proceed_checkout_purolator_small') == 'prevent') {
                    remove_action('woocommerce_proceed_to_checkout',
                        'woocommerce_button_proceed_to_checkout', 20, 2);
                    return __(get_option('prevent_proceed_checkout_purolator_small'));
                }
                else {
                    return __(get_option('allow_proceed_checkout_purolator_small'));
                }
            }

            /**
             * Check is free shipping or not
             * @param $coupon
             * @return string
             */
            function purolatorSmpkgFreeShipping($coupon)
            {
                foreach ($coupon as $key => $value) {
                    if ($value->get_free_shipping() == 1) {
                        $rates = array(
                            'id' => 'free',
                            'label' => 'Free Shipping',
                            'cost' => 0
                        );
                        $this->add_rate($rates);
                        return 'y';
                    }
                }
//               return 'n';
            }
        }

    }
}
