<?php
/*
  Plugin Name: Small Package Quotes - Purolator Edition
  Plugin URI: https://eniture.com/products/
  Description: Dynamically retrieves your negotiated shipping rates from Purolator and displays the results in the WooCommerce shopping cart.
  Version: 2.0.1
  Author: Eniture Technology
  Author URI: http://eniture.com/
  Text Domain: eniture-technology
  License: GPL version 2 or later - http://www.eniture.com/
 */
/**
 * Woo Check Update
 * @package     Woocommerce Purolator Small
 * @author      <https://eniture.com/>
 * @copyright   Copyright (c) 2017, Eniture
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

if (!function_exists('is_plugin_active')) {
    require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

/**
 * Check woocommerce installlation 
 */
if (!is_plugin_active('woocommerce/woocommerce.php')) {
    add_action('admin_notices', 'purolator_small_wc_avaibility_err');
}

/**
 * WC availability error
 */
function purolator_small_wc_avaibility_err()
{
    $class = "error";
    $message = "Small Package Quotes - Purolator Edition is enabled but not effective. It requires WooCommerce to work, please <a target='_blank' href='https://wordpress.org/plugins/woocommerce/installation/'>Install</a> WooCommerce Plugin.";
    echo"<div class=\"$class\"> <p>$message</p></div>";
}
/**
 * Include Plugin Files
 */
require_once ( 'helper/en_helper_class.php' );
require_once ( 'db/purolator-small-db.php' );
require_once ( 'purolator-small-admin-filter.php' );
require_once ( 'purolator-small-shipping-class.php' );
require_once ( 'template/connection-settings.php' );
require_once ( 'template/quote-settings.php' );
require_once ( 'template/product-detail.php' );
require_once ( 'js/purolator-small-js.php' );
require_once ( 'warehouses/save-warehouse.php' );
require_once ( 'warehouses/distance-request.php' );
require_once ( 'purolator-small-test-connection.php' );
require_once ( 'purolator-small-carrier-service.php' );
require_once ( 'purolator-small-group-package.php' );
require_once ( 'purolator-small-wc-update-change.php' );
require_once ( ABSPATH . 'wp-admin/includes/upgrade.php' );
require_once ( 'purolator-small-curl-class.php' );
require_once ( 'order-details/en-puro-small-order-widget-details.php' );



add_action('admin_init', 'purolator_small_check_woo_version');

/**
 * Check woocommerce version compatibility
 */
function purolator_small_check_woo_version()
{
    $wcPluginVersion = new purolator_Get_Shipping_Quotes();
    $woo_version = $wcPluginVersion->purolator_small_wc_version_number();
    $version = '2.6';
    if (!version_compare($woo_version["woocommerce_plugin_version"], $version,
            ">=")) {
        add_action('admin_notices', 'purolator_small_wc_version_failure');
    }
}

/**
 * WC Version Failure
 */
function purolator_small_wc_version_failure()
{

    ?>
    <div class="notice notice-error">
        <p>
    <?php
    _e('Small Package Quotes - Purolator Edition plugin requires WooCommerce version 2.6 or higher to work. Functionality may not work properly.',
        'wwe-woo-version-failure');

    ?>
        </p>
    </div>
    <?php
}
if (in_array('woocommerce/woocommerce.php',
        apply_filters('active_plugins', get_option('active_plugins')))) {
    if (!isset($_SESSION)) {
        session_start();
    }

    /**
     * Load scripts for purolator Small
     */
    add_action('admin_enqueue_scripts', 'purolator_small_admin_script');

    /**
     * Admin Script
     */
    function purolator_small_admin_script()
    {
        wp_enqueue_script('purolator_small_script',
            plugin_dir_url(__FILE__) . '/js/purolator-small-warehouse.js',
            array(), '1.0.0');
        wp_localize_script('purolator_small_script', 'script',
            array(
            'pluginsUrl' => plugins_url(),
        ));

        wp_register_style('purolator_small_style',
            plugin_dir_url(__FILE__) . '/css/purolator-small-style.css', false,
            '1.0.0');
        wp_enqueue_style('purolator_small_style');
    }
    add_filter('plugin_action_links', 'purolator_small_add_action_plugin', 10, 5);

    /**
     * purolator Small action links
     * @staticvar $plugin
     * @param $actions
     * @param $plugin_file
     */
    function purolator_small_add_action_plugin($actions, $plugin_file)
    {
        static $plugin;
        if (!isset($plugin))
            $plugin = plugin_basename(__FILE__);
        if ($plugin == $plugin_file) {
            $settings = array('settings' => '<a href="admin.php?page=wc-settings&tab=purolator_small">' . __('Settings',
                    'General') . '</a>');
            $site_link = array('support' => '<a href="https://eniture.com/support/" target="_blank">Support</a>');
            $actions = array_merge($settings, $actions);
            $actions = array_merge($site_link, $actions);
        }
        return $actions;
    }
    /**
     * purolator Small Activation Hook   (purolator-small-db function are included)
     */
    register_activation_hook(__FILE__, 'create_purolator_small_wh_db');
    register_activation_hook(__FILE__, 'create_purolator_small_option');

    /**
     * purolator Small Action And Filters   (purolator-small-admin-filter functions are used as add_filter and add_action)
     * 
     * purolator-small-shipping-class main function purolator_small_init included as add action.
     */
    add_filter('woocommerce_shipping_methods', 'add_purolator_small');
    add_filter('woocommerce_get_settings_pages',
        'purolator_small_shipping_sections');
    add_action('woocommerce_shipping_init', 'purolator_small_init');
    add_filter('woocommerce_package_rates', 'purolator_small_hide_shipping');
    add_action('init', 'purolator_small_no_method_available');
    add_filter('woocommerce_shipping_calculator_enable_city', '__return_true');
}

define("en_woo_plugin_purolator_small", "purolator_small");

add_action('wp_enqueue_scripts', 'en_purolator_small_frontend_checkout_script');

/**
 * Load Frontend scripts for ODFL
 */
function en_purolator_small_frontend_checkout_script()
{
    wp_enqueue_script('jquery');
    wp_enqueue_script('en_purolator_small_frontend_checkout_script',
        plugin_dir_url(__FILE__) . 'front/js/en-purolator-small-checkout.js',
        array(), '1.0.0');
    wp_localize_script('en_purolator_small_frontend_checkout_script',
        'frontend_script',
        array(
        'pluginsUrl' => plugins_url(),
    ));
}
add_action('upgrader_process_complete','en_pur_sml_add_order_details_table_function', 10);

add_action('wp_enqueue_scripts', 'en_puro_small_frontend_checkout_script');



/**
 * Load Frontend scripts for ODFL
 */
function en_puro_small_frontend_checkout_script()
{
    wp_enqueue_script('jquery');
    wp_enqueue_script('en_puro_small_frontend_checkout_script',
        plugin_dir_url(__FILE__) . 'front/js/en-purolator-small-checkout.js',
        array(), '1.0.0');
    wp_localize_script('en_puro_small_frontend_checkout_script',
        'frontend_script', array(
        'pluginsUrl' => plugins_url(),
    ));
}
