<?php
/**
 * Save Warehouse
 * @package     Woocommerce Purolator Small
 * @author      <https://eniture.com/>
 * @copyright   Copyright (c) 2017, Eniture
 */
    if ( ! defined( 'ABSPATH' ) ) {
	exit; 
    }
    
        add_action( 'wp_ajax_purolator_small_get_address', 'purolator_small_address_ajax' );
        add_action( 'wp_ajax_nopriv_purolator_small_get_address', 'purolator_small_address_ajax' );
    /**
     * Get Address From ZipCode Using API
     */
        function purolator_small_address_ajax() {
            $zipCode = ( isset( $_POST['origin_zip'] ) ) ? sanitize_text_field( preg_replace( '/\s+/', '', $_POST['origin_zip'] ) ) : "";
            
            if ( $zipCode ) {

                $accessLevel    = 'address';
                $resp_json      = Get_purolator_small_distance::purolator_small_address($zipCode, $accessLevel);
                $map_result     = json_decode($resp_json, true);
                $city           = "";
                $state          = "";
                $country        = "";
                $postcode_localities = 0;
                $city_option    = array();
                if( isset( $map_result['error'] ) && !empty( $map_result['error'] ) ) {
                    echo json_encode( array( 'apiResp' => 'apiErr' ) );
                    exit;
                }

                if ( count( $map_result['results'] ) == 0 ) {
                    echo json_encode( array('result' => 'false' ) );
                    exit;
                }

                $first_city = '';
                if (count($map_result['results']) > 0) {
                    $arrComponents = $map_result['results'][0]['address_components'];
                    if ($map_result['results'][0]['postcode_localities']) {
                        foreach ($map_result['results'][0]['postcode_localities'] as $index => $component) {
                            $first_city = ($index == 0) ? $component : $first_city;
                            $city_option .= '<option value="' . trim($component) . ' "> ' . $component . ' </option>';
                        }

                        $city = '<select id="' . $address_type . '_city" class="city-multiselect select purolator_small_multi_state city_select_css" name="' . $address_type . '_city" aria-required="true" aria-invalid="false">
                            ' . $city_option . '</select>';
                        $postcode_localities = 1;
                    } elseif ($arrComponents) {
                        foreach ($arrComponents as $index => $component) {
                            $type = $component['types'][0];
                            if ($city == "" && ( $type == "sublocality_level_1" || $type == "locality" )) {
                                $city_name = trim($component['long_name']);
                            }
                        }
                    }

                    if ($arrComponents) {
                        foreach ($arrComponents as $index => $state_app) {
                            $type = $state_app['types'][0];
                            if ($state == "" && ( $type == "administrative_area_level_1" )) {
                                $state_name = trim($state_app['short_name']);
                                $state = $state_name;
                            }

                            if ($country == "" && ( $type == "country" )) {
                                $country_name = trim($state_app['short_name']);
                                $country = $country_name;
                            }
                        }
                    }
                    echo json_encode(array('first_city' => $first_city, 'city' => $city_name, 'city_option' => $city, 'state' => $state, 'country' => $country, 'postcode_localities' => $postcode_localities));
                    exit;
                }
            }
        }
        
    /**
     * Validate Input Fields
     * @param $sPostData
     * @return string
     */   
        function validatedPostData($sPostData)
        {
            foreach ($sPostData as $key => $tag) 
        {
            $check_characters = preg_match('/[#$%@^&_*!()+=\-\[\]\';,.\/{}|":<>?~\\\\]/', $tag);
            if ($check_characters != 1 ) 
            {
                if ($key === 'city' || $key === 'nickname' )
                {
                    $data[$key] = sanitize_text_field($tag);
                } else {
                    $data[$key] = preg_replace( '/\s+/', '', sanitize_text_field($tag));
                } 
                    
                
            } else {
                $data[$key] = 'Error';
            }
        }
   
            return $data;
        }
        
        
    /**
     * Filtered Data Array
     * @param $validateData
     * @return array
     */    
        function purolator_small_filtered_data( $validateData ) {
            return array(
                'city'      => $validateData["city"],
                'state'     => $validateData["state"],
                'zip'       => preg_replace( '/\s+/', '', $validateData["zip"] ),
                'country'   => $validateData["country"],
                'location'  => $validateData["location"],                     
                'nickname'  => ( isset( $validateData["nickname"] ) ) ? $validateData["nickname"] : "",
            );
       }
       
        add_action('wp_ajax_purolator_small_save_warehouse', 'purolator_small_save_warehouse');
        add_action('wp_ajax_nopriv_purolator_small_save_warehouse', 'purolator_small_save_warehouse');
        
    /**
     * Save Warehouse Function
     */
        function purolator_small_save_warehouse() {
            global $wpdb;
            
            foreach ($_POST as $key => $post){
                $saveWhData[$key] = sanitize_text_field( $post );
            }
            
            $input_data_arr = array(
                'city'      => $saveWhData['origin_city'],
                'state'     => $saveWhData['origin_state'],
                'zip'       => $saveWhData['origin_zip'],
                'country'   => $saveWhData['origin_country'],
                'location'  => $saveWhData['location'],
            );
            
            $validateData   =  validatedPostData($input_data_arr);

            $getWarehouse  = $wpdb->get_results(
                  "SELECT * FROM ".$wpdb->prefix."warehouse WHERE city = '" . $validateData["city"] . "' && state = '" . $validateData["state"] . "' && zip = '" . $validateData["zip"] . "'");

            if($validateData["city"] != 'Error')
            {
                $data = purolator_small_filtered_data( $validateData );
               
                if ( isset( $validateData["city"] ) ) {
                    
                    $rawWarehouseId = sanitize_text_field ( $_POST['origin_id'] );
                    $warehouseId        = isset( $rawWarehouseId  ) ? intval( $rawWarehouseId ) : "";
                  
                    if ( $warehouseId && empty( $getWarehouse ) ) {
                        $update_qry = $wpdb->update(
                            $wpdb->prefix.'warehouse', $data, array('id' => $warehouseId)
                        );
                    } else {
                        if ( empty( $getWarehouse ) ) {
                            $insert_qry = $wpdb->insert(
                                $wpdb->prefix.'warehouse', $data
                            );
                        }
                    }
                }

              $lastid = $wpdb->insert_id;
              if ($lastid == 0) {
                  $lastid = $warehouseId;
              }
              $warehous_list = array('origin_city' => $data["city"], 'origin_state' => $data["state"], 'origin_zip' => $data["zip"], 'origin_country' => $data["country"], 'insert_qry' => $insert_qry, 'update_qry' => $update_qry, 'id' => $lastid);
              echo json_encode($warehous_list);
              exit;
            }
            else {
                echo "false";
                exit;
            }
             
            
          }
        

        add_action('wp_ajax_purolator_small_edit_warehouse', 'purolator_small_edit_warehouse');
        add_action('wp_ajax_nopriv_purolator_small_edit_warehouse', 'purolator_small_edit_warehouse');
    /**
     * Edit Warehouse Function
     * @global $wpdb
     */
        function purolator_small_edit_warehouse() {
            global $wpdb;
            $rawWarehouseeEditId = sanitize_text_field ( $_POST['edit_id'] );
            $warehouseId        = isset( $rawWarehouseeEditId  ) ? intval( $rawWarehouseeEditId ) : "";
            
            $warehousList      = $wpdb->get_results(
                    "SELECT id, city, state, zip, country 
              FROM ".$wpdb->prefix . "warehouse WHERE id=$warehouseId"
            );
            echo json_encode($warehousList);
            exit;
        }
        

        add_action('wp_ajax_purolator_small_delete_warehouse', 'purolator_small_delete_warehouse_ajax');
        add_action('wp_ajax_nopriv_purolator_small_delete_warehouse', 'purolator_small_delete_warehouse_ajax');
    /**
     * Delete Warehouse Function
     * @global $wpdb
     */
        function purolator_small_delete_warehouse_ajax() {
            global $wpdb;
            $rawWarehouseeDeleteId = sanitize_text_field ( $_POST['delete_id'] );
            $warehouseId        = isset( $rawWarehouseeDeleteId  ) ? intval( $rawWarehouseeDeleteId ) : "";
            $qry = $wpdb->delete($wpdb->prefix.'warehouse', array('id' => $warehouseId, 'location' => 'warehouse'));
            echo $qry;
            exit;
        }

        add_action('wp_ajax_purolator_small_save_dropship', 'purolator_small_save_dropship_ajax');
        add_action('wp_ajax_nopriv_purolator_small_save_dropship', 'purolator_small_save_dropship_ajax');
    /**
     * Save Dropship Function
     * @global $wpdb
     */
        function purolator_small_save_dropship_ajax() {
            global $wpdb;
            
            foreach ($_POST as $key => $post){
                $saveDsData[$key] = sanitize_text_field( $post );
            }
            
            $input_data_arr = array(
                'city'      => $saveDsData['dropship_city'],
                'state'     => $saveDsData['dropship_state'],
                'zip'       => $saveDsData['dropship_zip'],
                'country'   => $saveDsData['dropship_country'],
                'location'  => $saveDsData['location'],
                'nickname'  => $saveDsData['nickname'],
            );
            
          $validateData   =  validatedPostData($input_data_arr);
         
            $getDropship = $wpdb->get_results(
                    "SELECT * FROM ".$wpdb->prefix."warehouse WHERE city = '" . $validateData["city"] . "' && state = '" . $validateData["state"] . "' && zip = '" . $validateData["zip"] . "' && nickname = '" . $validateData["nickname"] . "'");
            
            if($validateData["city"] != 'Error' && $validateData["nickname"] != 'Error')
            {
                $data = purolator_small_filtered_data( $validateData );
                    if ( isset( $validateData["city"] ) ) {
                        
                        $rawDropshipId = sanitize_text_field ( $_POST['dropship_id'] );
                        $dropshipId        = isset( $rawDropshipId  ) ? intval( $rawDropshipId ) : "";
                        
                        if ( $dropshipId != '' && empty( $getDropship ) ) {

                            $update_qry = $wpdb->update(
                                    $wpdb->prefix.'warehouse', $data, array( 'id' => $dropshipId )
                            );
                        } else {

                            if ( empty( $getDropship ) ) {
                                $insert_qry = $wpdb->insert(
                                        $wpdb->prefix.'warehouse', $data
                                );
                            }
                        }
                    }

                $lastid = $wpdb->insert_id;
                if ($lastid == 0) {
                    $lastid = $dropshipId;
                }

                $warehous_list = array('nickname' => $data["nickname"], 'origin_city' => $data["city"], 'origin_state' => $data["state"], 'origin_zip' => $data["zip"], 'origin_country' => $data["country"], 'insert_qry' => $insert_qry, 'update_qry' => $update_qry, 'id' => $lastid);
                echo json_encode($warehous_list);
                exit;
            }
            else {
                echo "false";
                exit;
            }

            
        }

        add_action('wp_ajax_purolator_small_edit_dropship', 'purolator_small_edit_dropship_ajax');
        add_action('wp_ajax_nopriv_purolator_small_edit_dropship', 'purolator_small_edit_dropship_ajax');
    /**
     * Edit Dropship Function
     * @global $wpdb
     */
        function purolator_small_edit_dropship_ajax() {
            global $wpdb;
            
            $rawDropshipEditId = sanitize_text_field ( $_POST['dropship_edit_id'] );
            $dropshipId        = isset( $rawDropshipEditId  ) ? intval( $rawDropshipEditId ) : "";
            
            $dropshipList      = $wpdb->get_results(
                    "SELECT id, city, state, zip, country, nickname 
              FROM ".$wpdb->prefix . "warehouse WHERE id=$dropshipId"
            );
            echo json_encode($dropshipList);
            exit;
        }
        
        add_action('wp_ajax_purolator_small_delete_dropship', 'purolator_small_delete_dropship_ajax');
        add_action('wp_ajax_nopriv_purolator_small_delete_dropship', 'purolator_small_delete_dropship_ajax');
    /**
     * Delete Dropship Function
     * @global $wpdb
     */
        function purolator_small_delete_dropship_ajax() {
            global $wpdb;
            
            $rawDropshipDeleteId = sanitize_text_field ( $_POST['dropship_delete_id'] );
            $dropshipId        = isset( $rawDropshipDeleteId  ) ? intval( $rawDropshipDeleteId ) : "";
               
            $dropshipIdArr    = array( $dropshipId );

            $ser = maybe_serialize($dropshipIdArr);
            $getPostId        = $wpdb->get_results("SELECT group_concat(post_id) as post_ids_list FROM `".$wpdb->prefix ."postmeta` WHERE `meta_key` = '_dropship_location' AND (`meta_value` LIKE '%".$ser."%' OR `meta_value` = '".$dropshipId."')");
            $postId            = reset($getPostId)->post_ids_list;
            
            if(isset($postId)){
                $wpdb->query("UPDATE `".$wpdb->prefix ."postmeta` SET `meta_value` = '' WHERE `meta_key` = '_enable_dropship' AND `post_id` IN ($postId)");
            }
            
            $qry = $wpdb->delete($wpdb->prefix."warehouse", array('id' => $dropshipId, 'location' => 'dropship'));
            echo $qry;
            exit;
        }